@@ -1,5 +1,5 @@
 /* Copyright (c) 1993  X Consortium
-   Copyright (C) 2002-2005 RealVNC Ltd.  All Rights Reserved.
+   Copyright (C) 2002-2008 RealVNC Ltd.  All Rights Reserved.
 
 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
@@ -91,8 +91,8 @@ extern "C" {
 #endif
 }
 
-#define XVNCVERSION "Free Edition 4.1.1"
-#define XVNCCOPYRIGHT ("Copyright (C) 2002-2005 RealVNC Ltd.\n" \
+#define XVNCVERSION "Free Edition 4.1.3"
+#define XVNCCOPYRIGHT ("Copyright (C) 2002-2008 RealVNC Ltd.\n" \
                        "See http://www.realvnc.com for information on VNC.\n")
 
 
@@ -980,12 +980,11 @@ static Bool vncRandRGetInfo (ScreenPtr pScreen, Rotation *rotations)
   for (i = 0; i < pvfb->rrScreenSizesDefined; i++)
   {
     RRScreenSizePtr pSize;
-    int mmWidth = (pvfb->rrScreenSizes[i].width * 254) / 1000;
-    int mmHeight = (pvfb->rrScreenSizes[i].height * 254) / 1000;
 
     pSize = RRRegisterSize(pScreen,
 		pvfb->rrScreenSizes[i].width, pvfb->rrScreenSizes[i].height,
-		mmWidth, mmHeight);
+		(pvfb->rrScreenSizes[i].width * 254 + dpi * 5) / (dpi * 10),
+		(pvfb->rrScreenSizes[i].height * 254 + dpi * 5) / (dpi * 10));
     if (!pSize)
       return FALSE;
     RRRegisterRate(pScreen, pSize, 60);
@@ -1146,11 +1145,12 @@ static Bool vncRandRSetConfig (ScreenPtr pScreen, Rotation rotation,
 		    int	rate, RRScreenSizePtr pSize)
 {
   vfbScreenInfoPtr pvfb = &vfbScreens[pScreen->myNum];
+  int dpi = monitorResolution ? monitorResolution : 100;
 
   pScreen->width = pSize->width;
   pScreen->height = pSize->height;
-  pScreen->mmWidth = pSize->mmWidth;
-  pScreen->mmHeight = pSize->mmHeight;
+  pScreen->mmWidth = (pScreen->width * 254 + dpi * 5) / (dpi * 10);
+  pScreen->mmHeight = (pScreen->height * 254 + dpi * 5) / (dpi * 10);
   vfbResizeFramebufferMemory(pScreen);
   vncHooksResizeScreen(pScreen);
   xf86SetRootClip(pScreen, TRUE);
